16.152. cdist-type__systemd_unit(7) — cdist 6.9.4 documentation

# 16.152. cdist-type__systemd_unit(7)

## 16.152.1. NAME

cdist-type__systemd_unit - Install a systemd unit

## 16.152.2. DESCRIPTION

This type manages systemd units in `/etc/systemd/system/`. It can install, enable and start a systemd unit. This is particularly useful on systems which take advantage of systemd heavily (e.g., CoreOS). For more information about systemd units, see SYSTEMD.UNIT(5).

## 16.152.3. REQUIRED PARAMETERS

None.

## 16.152.4. OPTIONAL PARAMETERS

enablement-state

  'enabled', 'disabled' or 'masked', where:

  enabled

    enables the unit

  disabled

    disables the unit

  masked

    masks the unit

source

  Path to the config file. If source is '-' (dash), take what was written to stdin as the config file content.

state

  'present' or 'absent', defaults to 'present' where:

  present

    the unit (or its mask) is installed

  absent

    The unit is stopped, disabled and uninstalled. If the unit was masked, the mask is removed.

## 16.152.5. BOOLEAN PARAMETERS

restart

  Start the unit if it was inactive. Restart the unit if the unit file changed. Stop the unit if new `enablement-state` is `masked`.

## 16.152.6. MESSAGES

None.

## 16.152.7. EXAMPLES

    # Installs, enables and starts foobar.service
    __systemd_unit foobar.service \
        --source "${__manifest}/files/foobar.service" \
        --enablement-state enabled \
        --restart

    # Disables the unit
    __systemd_unit foobar.service --enablement-state disabled

    # Stops, disables and uninstalls foobar.service
    __systemd_unit foobar.service --state absent

## 16.152.8. AUTHORS

Ľubomír Kučera <lubomir.kucera.jr at gmail.com>

## 16.152.9. COPYING

Copyright (C) 2017 Ľubomír Kučera. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.